@@ -4,7 +4,7 @@
 <context>
     <name>KvManager::AboutDialog</name>
     <message>
-        <location filename="../../about.ui" line="131"/>
+        <location filename="../../about.ui" line="135"/>
         <source>License</source>
         <translation type="unfinished"></translation>
     </message>
@@ -112,7 +112,7 @@ settings of this theme.
     </message>
     <message>
         <location filename="../../kvantummanager.ui" line="343"/>
-        <location filename="../../kvantummanager.ui" line="2075"/>
+        <location filename="../../kvantummanager.ui" line="2086"/>
         <source>Save</source>
         <translation>Zapisz</translation>
     </message>
@@ -638,7 +638,18 @@ By default, tree branches have indicators but no line.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2057"/>
+        <location filename="../../kvantummanager.ui" line="1907"/>
+        <source>They may look like dotted rectangles
+on focused buttons and other widgets.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../kvantummanager.ui" line="1911"/>
+        <source>Remove focus rectangles</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../kvantummanager.ui" line="2068"/>
         <source>Use the active theme for all apps!
 
 This Needs saving to take effect.</source>
@@ -849,8 +860,8 @@ both horizontally and vertically.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="1907"/>
-        <location filename="../../kvantummanager.ui" line="1921"/>
+        <location filename="../../kvantummanager.ui" line="1918"/>
+        <location filename="../../kvantummanager.ui" line="1932"/>
         <source>Drag windows from their menubars, primary toolbars
 or anywhere possible (and not only from their title bars)?
 
@@ -1045,7 +1056,7 @@ between toolbar separators.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="1914"/>
+        <location filename="../../kvantummanager.ui" line="1925"/>
         <source>Drag from:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1155,134 +1166,134 @@ This option will hide these.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="1948"/>
+        <location filename="../../kvantummanager.ui" line="1959"/>
         <source>Application Themes</source>
         <translation>Motywy aplikacji</translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="1954"/>
+        <location filename="../../kvantummanager.ui" line="1965"/>
         <source>&lt;center&gt;Here you could assign themes to specific applications.&lt;/center&gt;&lt;br&gt;&lt;center&gt;For each theme, you could add a comma-separated list of executables whose applications should use that theme instead of the active theme. After doing so for all of your chosen themes, save the result by clicking on the &lt;i&gt;Save&lt;/i&gt; button!&lt;/center&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="1989"/>
+        <location filename="../../kvantummanager.ui" line="2000"/>
         <source>Installed Theme</source>
         <translation>Zainstalowany motyw</translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2005"/>
+        <location filename="../../kvantummanager.ui" line="2016"/>
         <source>Application(s)</source>
         <translation>Aplikacja/e</translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2034"/>
+        <location filename="../../kvantummanager.ui" line="2045"/>
         <source>app1,app2,app3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2062"/>
+        <location filename="../../kvantummanager.ui" line="2073"/>
         <source>Remove List</source>
         <translation>Usuń listę</translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2069"/>
+        <location filename="../../kvantummanager.ui" line="2080"/>
         <source>Save the current list of apps</source>
         <translation>Zapisz obecną listę aplikacji</translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2072"/>
+        <location filename="../../kvantummanager.ui" line="2083"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Save the current list of applications with their corresponding themes!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2099"/>
-        <location filename="../../kvantummanager.ui" line="2105"/>
+        <location filename="../../kvantummanager.ui" line="2110"/>
+        <location filename="../../kvantummanager.ui" line="2116"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2102"/>
+        <location filename="../../kvantummanager.ui" line="2113"/>
         <source>Quit</source>
         <translation>Zakończ</translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2115"/>
+        <location filename="../../kvantummanager.ui" line="2126"/>
         <source>Preview the active theme
 or update its preview.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2119"/>
+        <location filename="../../kvantummanager.ui" line="2130"/>
         <source>Preview</source>
         <translation>Podgląd</translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2126"/>
+        <location filename="../../kvantummanager.ui" line="2137"/>
         <source>About</source>
         <translation>O programie</translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2149"/>
+        <location filename="../../kvantummanager.ui" line="2160"/>
         <source>What&apos;s This?</source>
         <translation>Co to jest?</translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2152"/>
+        <location filename="../../kvantummanager.ui" line="2163"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Click on this button and then click on a GUI element that has &amp;quot;What&apos;s This&amp;quot; tooltip  to get information about what it does.&lt;/p&gt;&lt;p&gt;There are also ordinary tooltips but this kind of tooltip will not disappear until you click somewhere.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../kvantummanager.ui" line="2155"/>
+        <location filename="../../kvantummanager.ui" line="2166"/>
         <source>Help</source>
         <translation>Pomoc</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="197"/>
+        <location filename="../../KvantumManager.cpp" line="195"/>
         <source>Open Kvantum Theme Folder...</source>
         <translation>Otwórz folder motywów Kvantum…</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="384"/>
-        <location filename="../../KvantumManager.cpp" line="401"/>
-        <location filename="../../KvantumManager.cpp" line="417"/>
-        <location filename="../../KvantumManager.cpp" line="428"/>
-        <location filename="../../KvantumManager.cpp" line="439"/>
-        <location filename="../../KvantumManager.cpp" line="466"/>
-        <location filename="../../KvantumManager.cpp" line="481"/>
-        <location filename="../../KvantumManager.cpp" line="528"/>
-        <location filename="../../KvantumManager.cpp" line="544"/>
+        <location filename="../../KvantumManager.cpp" line="382"/>
+        <location filename="../../KvantumManager.cpp" line="399"/>
+        <location filename="../../KvantumManager.cpp" line="415"/>
+        <location filename="../../KvantumManager.cpp" line="426"/>
+        <location filename="../../KvantumManager.cpp" line="437"/>
+        <location filename="../../KvantumManager.cpp" line="464"/>
+        <location filename="../../KvantumManager.cpp" line="479"/>
+        <location filename="../../KvantumManager.cpp" line="526"/>
+        <location filename="../../KvantumManager.cpp" line="542"/>
         <source>Kvantum</source>
         <translation>Kvantum</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="468"/>
+        <location filename="../../KvantumManager.cpp" line="466"/>
         <source>First you have to delete its modified version!</source>
         <translation>Musisz najpierw usunąć zmodyfikowaną wersję!</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="492"/>
-        <location filename="../../KvantumManager.cpp" line="646"/>
-        <location filename="../../KvantumManager.cpp" line="2474"/>
+        <location filename="../../KvantumManager.cpp" line="490"/>
+        <location filename="../../KvantumManager.cpp" line="644"/>
+        <location filename="../../KvantumManager.cpp" line="2480"/>
         <source>Confirmation</source>
         <translation>Potwierdzenie</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="607"/>
+        <location filename="../../KvantumManager.cpp" line="605"/>
         <source>%1 installed.</source>
         <translation>Zainstalowano %1.</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="777"/>
+        <location filename="../../KvantumManager.cpp" line="775"/>
         <source>%1 deleted.</source>
         <translation>Usunięto %1.</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="831"/>
+        <location filename="../../KvantumManager.cpp" line="829"/>
         <source>Theme changed to %1.</source>
         <translation>Zmieniono motyw na %1.</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="385"/>
+        <location filename="../../KvantumManager.cpp" line="383"/>
         <source>You have no permission to write here:</source>
         <translation>Nie masz uprawnień, aby tu zapisywać:</translation>
     </message>
@@ -1358,168 +1369,168 @@ or update its preview.</source>
         <translation>Wszędzie, gdzie to możliwe</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="387"/>
+        <location filename="../../KvantumManager.cpp" line="385"/>
         <source>Please fix that first!</source>
         <translation>Napraw to najpierw!</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="399"/>
+        <location filename="../../KvantumManager.cpp" line="397"/>
         <source>This file cannot be removed:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="418"/>
-        <location filename="../../KvantumManager.cpp" line="429"/>
+        <location filename="../../KvantumManager.cpp" line="416"/>
+        <location filename="../../KvantumManager.cpp" line="427"/>
         <source>This is not an installable Kvantum theme!</source>
         <translation>To nie jest instalowalny motyw Kvantum!</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="419"/>
+        <location filename="../../KvantumManager.cpp" line="417"/>
         <source>The name of an installable themes should not be &quot;Default&quot;.</source>
         <translation>Nazwa instalowanego motywu musi być inna niż &quot;Default&quot;.</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="420"/>
-        <location filename="../../KvantumManager.cpp" line="431"/>
-        <location filename="../../KvantumManager.cpp" line="441"/>
+        <location filename="../../KvantumManager.cpp" line="418"/>
+        <location filename="../../KvantumManager.cpp" line="429"/>
+        <location filename="../../KvantumManager.cpp" line="439"/>
         <source>Please select another directory!</source>
         <translation>Wybierz inny katalog!</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="430"/>
+        <location filename="../../KvantumManager.cpp" line="428"/>
         <source>Installable themes should not have # in their names.</source>
         <translation>Nazwa instalowanego motywu nie może zawierać znaku &quot;#&quot;.</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="440"/>
+        <location filename="../../KvantumManager.cpp" line="438"/>
         <source>This is not a Kvantum theme folder!</source>
         <translation>To nie jest folder motywu Kvantum!</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="467"/>
+        <location filename="../../KvantumManager.cpp" line="465"/>
         <source>The theme already exists in modified form.</source>
         <translation>Motyw już istnieje w zmodyfikowanej formie.</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="482"/>
+        <location filename="../../KvantumManager.cpp" line="480"/>
         <source>You have selected an installed theme folder.</source>
         <translation>Wybrano foler zainstalowanego motywu.</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="483"/>
+        <location filename="../../KvantumManager.cpp" line="481"/>
         <source>Please choose another directory!</source>
         <translation>Wybierz inny katalog!</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="493"/>
+        <location filename="../../KvantumManager.cpp" line="491"/>
         <source>The theme already exists.</source>
         <translation>Motyw już istnieje.</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="494"/>
+        <location filename="../../KvantumManager.cpp" line="492"/>
         <source>Do you want to overwrite it?</source>
         <translation>Czy chcesz go zastąpić?</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="529"/>
+        <location filename="../../KvantumManager.cpp" line="527"/>
         <source>This theme is also installed as root in:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="531"/>
+        <location filename="../../KvantumManager.cpp" line="529"/>
         <source>The user installation will take priority.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="545"/>
+        <location filename="../../KvantumManager.cpp" line="543"/>
         <source>This theme is also installed as user in:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="547"/>
+        <location filename="../../KvantumManager.cpp" line="545"/>
         <source>This installation will take priority.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="647"/>
+        <location filename="../../KvantumManager.cpp" line="645"/>
         <source>Do you really want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
         <translation>Czy na pewno chcesz usunąć &lt;i&gt;%1&lt;/i&gt;?</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="650"/>
+        <location filename="../../KvantumManager.cpp" line="648"/>
         <source>It could not be restored unless you have a copy of it.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="1181"/>
-        <location filename="../../KvantumManager.cpp" line="1200"/>
+        <location filename="../../KvantumManager.cpp" line="1180"/>
+        <location filename="../../KvantumManager.cpp" line="1199"/>
         <source>These are the settings that can be safely changed.&lt;br&gt;For the others, click &lt;i&gt;Save&lt;/i&gt; and then edit this file:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="1196"/>
-        <location filename="../../KvantumManager.cpp" line="2382"/>
+        <location filename="../../KvantumManager.cpp" line="1195"/>
+        <location filename="../../KvantumManager.cpp" line="2388"/>
         <source>These are the settings that can be safely changed.&lt;br&gt;For the others, edit this file:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="1564"/>
+        <location filename="../../KvantumManager.cpp" line="1577"/>
         <source>No description</source>
         <translation>Brak opisu</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2044"/>
+        <location filename="../../KvantumManager.cpp" line="2048"/>
         <source>A copy of the root config is created.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2055"/>
+        <location filename="../../KvantumManager.cpp" line="2059"/>
         <source>A copy was already created.</source>
         <translation>Kopia została już utworzona.</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2368"/>
+        <location filename="../../KvantumManager.cpp" line="2374"/>
         <source>Configuration saved.</source>
         <translation>Zapisano konfigurację.</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2475"/>
+        <location filename="../../KvantumManager.cpp" line="2481"/>
         <source>Do you want to revert to the default (root) settings of this theme?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2478"/>
+        <location filename="../../KvantumManager.cpp" line="2484"/>
         <source>You will lose the changes you might have made.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2513"/>
+        <location filename="../../KvantumManager.cpp" line="2519"/>
         <source>Restored the rool default settings of %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2514"/>
+        <location filename="../../KvantumManager.cpp" line="2520"/>
         <source>the default theme</source>
         <translation>domyślny motyw</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2651"/>
-        <location filename="../../KvantumManager.cpp" line="2652"/>
+        <location filename="../../KvantumManager.cpp" line="2657"/>
+        <location filename="../../KvantumManager.cpp" line="2658"/>
         <source>About Kvantum Manager</source>
         <translation>O Kvantum Manager</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2651"/>
+        <location filename="../../KvantumManager.cpp" line="2657"/>
         <source>Translators</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2649"/>
+        <location filename="../../KvantumManager.cpp" line="2655"/>
         <source>A tool for installing, selecting&lt;br&gt;and configuring &lt;a href=&apos;https://github.com/tsujan/Kvantum&apos;&gt;Kvantum&lt;/a&gt; themes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="2650"/>
+        <location filename="../../KvantumManager.cpp" line="2656"/>
         <source>Author: &lt;a href=&apos;mailto:tsujan2000@gmail.com?Subject=My%20Subject&apos;&gt;Pedram Pourang (aka. Tsu Jan)&lt;/a&gt; &lt;/center&gt;&lt;br&gt;</source>
         <translation>Autor: &lt;a href=&apos;mailto:tsujan2000@gmail.com?Subject=Temat&apos;&gt;Pedram Pourang (aka. Tsu Jan)&lt;/a&gt; &lt;/center&gt;&lt;br&gt;</translation>
     </message>
@@ -1534,19 +1545,19 @@ or update its preview.</source>
         <translation>domyślny</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="397"/>
+        <location filename="../../KvantumManager.cpp" line="395"/>
         <source>This directory cannot be removed:</source>
         <translation>Ten katalog nie może zostać usunięty:</translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="404"/>
+        <location filename="../../KvantumManager.cpp" line="402"/>
         <source>You might want to investigate the cause.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../KvantumManager.cpp" line="830"/>
-        <location filename="../../KvantumManager.cpp" line="1984"/>
-        <location filename="../../KvantumManager.cpp" line="2377"/>
+        <location filename="../../KvantumManager.cpp" line="828"/>
+        <location filename="../../KvantumManager.cpp" line="1988"/>
+        <location filename="../../KvantumManager.cpp" line="2383"/>
         <source>Active theme:</source>
         <translation>Aktywny motyw:</translation>
     </message>
@@ -1554,17 +1565,17 @@ or update its preview.</source>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../main.cpp" line="129"/>
+        <location filename="../../main.cpp" line="123"/>
         <source>Kvantum</source>
         <translation>Kvantum</translation>
     </message>
     <message>
-        <location filename="../../main.cpp" line="130"/>
+        <location filename="../../main.cpp" line="124"/>
         <source>Kvantum is not installed on your system.</source>
         <translation>Kvantum nie jest zainstalowany na Twoim systemie.</translation>
     </message>
     <message>
-        <location filename="../../main.cpp" line="131"/>
+        <location filename="../../main.cpp" line="125"/>
         <source>Please first install the Kvantum style plugin!</source>
         <translation>Najpierw zainstaluj wtyczkę motywów Kvantum!</translation>
     </message>
