@@ -31,12 +31,8 @@ public:
     splitter->setSizes (sizes);
     splitter_2->setSizes (sizes);
     treeWidget->sortItems (0, Qt::AscendingOrder);
-#if QT_VERSION < 0x050000
-    QTabBar *tb = tabWidget->findChild<QTabBar*>(QLatin1String("qt_tabwidget_tabbar"));
-    if (tb) tb->setUsesScrollButtons (false);
-#else
-    tabWidget->tabBar()->setUsesScrollButtons (false);
-#endif
+    treeWidget->setAlternatingRowColors (true);
+    tabWidget->tabBar()->setUsesScrollButtons (false); // to prevent tab scroll buttons at startup (-> main.cpp)
     QPushButton *pb1 = new QPushButton (QIcon (":/Icons/data/icon.svg"), QString());
     tabWidget_2->setCornerWidget (pb1, Qt::TopRightCorner);
     QPushButton *pb2 = new QPushButton (QIcon (":/Icons/data/icon.svg"), QString());
@@ -54,6 +50,9 @@ public:
     actionMenuButton->setMenu (menuFile);
     toolButton_8->setMenu (menuFile);
 
+    toolBar_2->addSeparator();
+    QLabel *label = new QLabel ("<center><b><i>Kvantum</i></b></center>");
+    toolBar_2->addWidget (label);
     toolBar_2->addSeparator();
     QComboBox *cb = new QComboBox();
     cb->addItems (QStringList() << "Kvantum" << "Qt" << "C++");
