@@ -107,28 +107,6 @@ static void setAppFont()
   }
 }
 
-/*static inline QColor overlayColor(QColor col, QColor overlayCol)
-{
-  if (!overlayCol.isValid()) return QColor(0,0,0);
-  if (!col.isValid()) return overlayCol;
-
-  qreal a1 = overlayCol.alphaF();
-  if (a1 == 1.0) return overlayCol;
-  qreal a0  = col.alphaF();
-
-  qreal a = (1.0 - a1) * a0 + a1;
-  qreal r = ((1.0 - a1) * a0 * col.redF() + a1 * overlayCol.redF()) / a;
-  qreal g = ((1.0 - a1) * a0 *col.greenF() + a1 * overlayCol.greenF()) / a;
-  qreal b = ((1.0 - a1) * a0 * col.blueF() + a1 * overlayCol.blueF()) / a;
-
-  QColor res;
-  res.setAlphaF(a);
-  res.setRedF(r);
-  res.setGreenF(g);
-  res.setBlueF(b);
-  return res;
-}*/
-
 void Style::polish(QWidget *widget)
 {
   if (!widget) return;
@@ -172,13 +150,15 @@ void Style::polish(QWidget *widget)
 
   //widget->setAttribute(Qt::WA_MouseTracking, true);
 
+  bool respectDarkness(hspec_.respect_darkness);
+
   /* respect the toolbar text color if the widget is shown after
      its parent toolbar and without repainting it (unlike in CE_ToolBar) */
   const label_spec tLspec = getLabelSpec(QStringLiteral("Toolbar"));
   QColor tColor = getFromRGBA(tLspec.normalColor);
-  if (enoughContrast(getFromRGBA(cspec_.textColor), tColor)
+  if (enoughContrast(standardPalette().color(QPalette::Active,QPalette::Text), tColor)
       && !qobject_cast<QToolButton*>(widget) // flat toolbuttons are dealt with at CE_ToolButtonLabel
-      && isStylableToolbar(pw))
+      && getStylableToolbarContainer(widget))
   {
     QColor inactiveCol = getFromRGBA(tLspec.normalInactiveColor);
     if (!inactiveCol.isValid())
@@ -186,21 +166,25 @@ void Style::polish(QWidget *widget)
     QColor disabledCol = tColor;
     disabledCol.setAlpha(102); // 0.4 * disabledCol.alpha()
 
-    /* as in Cantata (previously, also Krita and Amarok) */
-    QPalette palette = widget->palette();
-    palette.setColor(QPalette::Active, QPalette::ButtonText, tColor);
-    palette.setColor(QPalette::Inactive, QPalette::ButtonText, inactiveCol);
-    palette.setColor(QPalette::Disabled, QPalette::ButtonText, disabledCol);
-    palette.setColor(QPalette::Active, QPalette::WindowText, tColor);
-    palette.setColor(QPalette::Inactive, QPalette::WindowText, inactiveCol);
-    palette.setColor(QPalette::Disabled, QPalette::WindowText, disabledCol);
-    if (qobject_cast<QLabel*>(widget))
+    if (isStylableToolbar(pw)) // an immediate child of a stylable toolbar
     {
-      palette.setColor(QPalette::Active, QPalette::Text, tColor);
-      palette.setColor(QPalette::Inactive, QPalette::Text, inactiveCol);
-      palette.setColor(QPalette::Disabled, QPalette::Text, disabledCol);
+      /* as in Cantata (previously, also Krita and Amarok) */
+      QPalette palette = widget->palette();
+      palette.setColor(QPalette::Active, QPalette::ButtonText, tColor);
+      palette.setColor(QPalette::Inactive, QPalette::ButtonText, inactiveCol);
+      palette.setColor(QPalette::Disabled, QPalette::ButtonText, disabledCol);
+      palette.setColor(QPalette::Active, QPalette::WindowText, tColor);
+      palette.setColor(QPalette::Inactive, QPalette::WindowText, inactiveCol);
+      palette.setColor(QPalette::Disabled, QPalette::WindowText, disabledCol);
+      if (qobject_cast<QLabel*>(widget))
+      {
+        palette.setColor(QPalette::Active, QPalette::Text, tColor);
+        palette.setColor(QPalette::Inactive, QPalette::Text, inactiveCol);
+        palette.setColor(QPalette::Disabled, QPalette::Text, disabledCol);
+        respectDarkness = false; // we don't want to change its text color again
+      }
+      widget->setPalette(palette);
     }
-    widget->setPalette(palette);
 
     if (qobject_cast<QLineEdit*>(widget))
     {
@@ -218,8 +202,8 @@ void Style::polish(QWidget *widget)
       }
     }
     else if (qobject_cast<QComboBox*>(widget)
-             && (!getFrameSpec(QStringLiteral("ToolbarComboBox")).element.isEmpty()
-                 || !getInteriorSpec(QStringLiteral("ToolbarComboBox")).element.isEmpty()))
+            && (!getFrameSpec(QStringLiteral("ToolbarComboBox")).element.isEmpty()
+                || !getInteriorSpec(QStringLiteral("ToolbarComboBox")).element.isEmpty()))
     {
       tColor = getFromRGBA(getLabelSpec(QStringLiteral("ToolbarComboBox")).normalColor);
       if (tColor.isValid())
@@ -236,11 +220,23 @@ void Style::polish(QWidget *widget)
       }
     }
   }
+  else if (qobject_cast<QToolBar*>(pw) && qobject_cast<QLabel*>(widget))
+  { // on toolbars, labels get the button text color; that's corrected here
+    QPalette palette = widget->palette();
+    palette.setColor(QPalette::Active, QPalette::ButtonText,
+                     standardPalette().color(QPalette::Active,QPalette::WindowText));
+    palette.setColor(QPalette::Inactive, QPalette::ButtonText,
+                     standardPalette().color(QPalette::Inactive,QPalette::WindowText));
+    palette.setColor(QPalette::Disabled, QPalette::ButtonText,
+                     standardPalette().color(QPalette::Disabled,QPalette::WindowText));
+    widget->setPalette(palette);
+    respectDarkness = false;
+  }
 
-  if (hspec_.respect_darkness)
+  if (respectDarkness)
   {
-    QColor winCol = getFromRGBA(cspec_.windowColor);
-    if (winCol.isValid() && qGray(winCol.rgb()) <= 100 // there should be darkness to be respected
+    QColor winCol = standardPalette().color(QPalette::Active,QPalette::Window);
+    if (qGray(winCol.rgb()) <= 100 // there should be darkness to be respected
         // it's usual to define custom colors in text edits
         && !widget->inherits("QTextEdit") && !widget->inherits("QPlainTextEdit"))
     {
@@ -409,7 +405,7 @@ void Style::polish(QWidget *widget)
               {
                 if (tspec_now.menu_shadow_depth > 0)
                   getShadow(QStringLiteral("Menu"), getMenuMargin(true), getMenuMargin(false));
-                QList<int> tooltipS;
+                QList<qreal> tooltipS;
                 if (tspec_now.tooltip_shadow_depth > 0)
                 {
                   const frame_spec fspec = getFrameSpec(QStringLiteral("ToolTip"));
@@ -451,13 +447,12 @@ void Style::polish(QWidget *widget)
     /* Dolphin sets the background of its KItemListContainer's viewport
        to KColorScheme::View (-> kde-baseapps -> dolphinview.cpp).
        We force our base color here. */
-    QColor col = getFromRGBA(cspec_.baseColor);
-    if (col.isValid())
-    {
-      QPalette palette = widget->palette();
-      palette.setColor(widget->backgroundRole(), col);
-      widget->setPalette(palette);
-    }
+    QPalette palette = widget->palette();
+    palette.setColor(QPalette::Active, widget->backgroundRole(),
+                     standardPalette().color(QPalette::Active,QPalette::Base));
+    palette.setColor(QPalette::Inactive, widget->backgroundRole(),
+                     standardPalette().color(QPalette::Inactive,QPalette::Base));
+    widget->setPalette(palette);
     /* hack Dolphin's view */
     if (hspec_.transparent_dolphin_view && widget->autoFillBackground())
       widget->setAutoFillBackground(false);
@@ -483,13 +478,15 @@ void Style::polish(QWidget *widget)
       || widget->inherits("KSignalPlotter")) // probably has a bug
   {
     /* Text editors and some other widgets shouldn't have a translucent base color.
-       (line-edits are dealt with separately and only when needed.) */
+       (line-edits are dealt with separately and only when needed in "Kvantum.cpp".) */
     QPalette palette = widget->palette();
     QColor baseCol = palette.color(QPalette::Base);
     if (baseCol.isValid() && baseCol != Qt::transparent // for rare cases, like that of Kaffeine's file widget
         && baseCol.alpha() < 255)
     {
-      baseCol.setAlpha(255);
+      QColor winCol = palette.color(QPalette::Window);
+      winCol.setAlpha(255);
+      baseCol = overlayColor(winCol,baseCol);
       palette.setColor(QPalette::Base,baseCol);
       widget->setPalette(palette);
     }
@@ -535,16 +532,14 @@ void Style::polish(QWidget *widget)
     }
     else // in rare cases like KNotes' font combos or Kcalc
     {
-      QColor col = getFromRGBA(cspec_.textColor);
-      if (col.isValid())
+      QColor col = standardPalette().color(QPalette::Active,QPalette::Text);
+      QPalette palette = widget->palette();
+      if (col != palette.color(QPalette::Active,QPalette::Text))
       {
-        QPalette palette = widget->palette();
-        if (col != palette.color(QPalette::Active,QPalette::Text))
-        {
-          palette.setColor(QPalette::Active,QPalette::Text,col);
-          palette.setColor(QPalette::Inactive,QPalette::Text,col);
-          widget->setPalette(palette);
-        }
+        palette.setColor(QPalette::Active,QPalette::Text,col);
+        palette.setColor(QPalette::Inactive,QPalette::Text,
+                         standardPalette().color(QPalette::Inactive,QPalette::Text));
+        widget->setPalette(palette);
       }
     }
 
@@ -856,7 +851,7 @@ void Style::polish(QWidget *widget)
       {
         if (blurHelper_ == nullptr && tspec_now.popup_blurring)
         {
-          QList<int> tooltipS;
+          QList<qreal> tooltipS;
           if (tspec_now.tooltip_shadow_depth > 0)
           {
             const frame_spec fspec = getFrameSpec(QStringLiteral("ToolTip"));
@@ -1046,7 +1041,7 @@ QPalette Style::standardPalette() const
     return standardPalette_;
 
   QColor col1;
-  bool hasInactiveness (!tspec_.no_inactiveness);
+  bool hasInactiveness(!tspec_.no_inactiveness);
 
   /* background colors */
   QColor col = getFromRGBA(cspec_.windowColor);
@@ -1078,14 +1073,44 @@ QPalette Style::standardPalette() const
   col = getFromRGBA(cspec_.altBaseColor);
   if (col.isValid())
   {
+    if (col.alpha() < 255)
+    {
+      /* make the alternate base color opaque by applying it over the base color
+         because some apps (like Krusader) may ignore its translucency */
+      QColor baseCol = standardPalette().color(QPalette::Active,QPalette::Base);
+      baseCol.setAlpha(255);
+      col = overlayColor(baseCol,col);
+    }
     standardPalette_.setColor(QPalette::Active,QPalette::AlternateBase,col);
     standardPalette_.setColor(QPalette::Disabled,QPalette::AlternateBase,col);
     col1 = getFromRGBA(cspec_.inactiveAltBaseColor);
     if (col1.isValid() && hasInactiveness)
+    {
+      if (col1.alpha() < 255)
+      {
+        QColor baseCol = standardPalette().color(QPalette::Inactive,QPalette::Base);
+        baseCol.setAlpha(255);
+        col1 = overlayColor(baseCol,col1);
+      }
       standardPalette_.setColor(QPalette::Inactive,QPalette::AlternateBase,col1);
+    }
     else
       standardPalette_.setColor(QPalette::Inactive,QPalette::AlternateBase,col);
   }
+  else
+  {
+    col = standardPalette().color(QPalette::Active,QPalette::Base);
+    int v = col.value();
+    if (v < 127) v += 5; else v -= 5;
+    col.setHsv(col.hue(), col.saturation(), v);
+    standardPalette_.setColor(QPalette::Active,QPalette::AlternateBase,col);
+
+    col = standardPalette().color(QPalette::Inactive,QPalette::Base);
+    v = col.value();
+    if (v < 127) v += 5; else v -= 5;
+    col.setHsv(col.hue(), col.saturation(), v);
+    standardPalette_.setColor(QPalette::Inactive,QPalette::AlternateBase,col);
+  }
 
   col = getFromRGBA(cspec_.buttonColor);
   if (col.isValid())
